# inspired from fedora spec file
# Copyright (c) 2016 Shawn Iwinski <shawn@iwin.ski>
# License: MIT
# https://opensource.org/licenses/MIT

%define github_name    container-interop
%define composer_name  container-interop
%define composer_vendor container-interop

%define php_libdir %{_datadir}/php

%define __requires_exclude_from ^%{_datadir}/.*$

Name:      php-%{composer_name}
Version:   1.2.0
Release:   %mkrel 4
Summary:   Promoting the interoperability of container objects (DIC, SL, etc.)

Group:     Development/PHP
License:   MIT
URL:       https://github.com/container-interop/container-interop
Source0:   https://github.com/container-interop/container-interop/archive/%{github_name}-%{version}.tar.gz

BuildArch: noarch

# composer.json
Requires:  php-composer(psr/container) >= 1.0
# phpcompatinfo (computed from version 1.2.0)
Requires:  php >= 5.3.0
# Autoloader
Requires:  php-composer(fedora/autoloader)

# Composer
Provides:  php-composer(%{composer_vendor}/%{composer_name}) = %{version}


%description
container-interop tries to identify and standardize features in container
objects (service locators, dependency injection containers, etc.) to achieve
interoperability.

Through discussions and trials, we try to create a standard, made of common
interfaces but also recommendations.

If PHP projects that provide container implementations begin to adopt these
common standards, then PHP applications and projects that use containers can
depend on the common interfaces instead of specific implementations. This
facilitates a high-level of interoperability and flexibility that allows users
to consume any container implementation that can be adapted to these interfaces.

The work done in this project is not officially endorsed by the PHP-FIG [1],
but it is being worked on by members of PHP-FIG and other good developers. We
adhere to the spirit and ideals of PHP-FIG, and hope this project will pave the
way for one or more future PSRs.

Autoloader: %{php_libdir}/Interop/Container/autoload.php

[1] https://www.php-fig.org/


%prep
%setup -qn %{github_name}-%{version}

: Create autoloader
cat <<'AUTOLOAD' | tee src/Interop/Container/autoload.php
<?php
/**
 * Autoloader for %{name} and its' dependencies
 * (created by %{name}-%{version}-%{release}).
 *
 * @return \Symfony\Component\ClassLoader\ClassLoader
 */
require_once '%{php_libdir}/Fedora/Autoloader/autoload.php';

\Fedora\Autoloader\Autoload::addPsr4('Interop\\Container\\', __DIR__);

\Fedora\Autoloader\Dependencies::required([
    '%{php_libdir}/Psr/Container/autoload.php',
]);
AUTOLOAD

%build

%install
mkdir -p %{buildroot}%{php_libdir}
cp -rp src/* %{buildroot}%{php_libdir}/

%files
%doc LICENSE
%doc *.md
%doc composer.json
%doc docs
%dir %{php_libdir}/Interop
%{php_libdir}/Interop/Container


%changelog
* Sun Mar 20 2022 umeabot <umeabot> 1.2.0-4.mga9
+ Revision: 1806776
- Mageia 9 Mass Rebuild

* Wed Feb 12 2020 umeabot <umeabot> 1.2.0-3.mga8
+ Revision: 1498597
- Mageia 8 Mass Rebuild

* Wed Sep 19 2018 umeabot <umeabot> 1.2.0-2.mga7
+ Revision: 1272964
- Mageia 7 Mass Rebuild

* Wed May 10 2017 guillomovitch <guillomovitch> 1.2.0-1.mga6
+ Revision: 1099956
- imported package php-container-interop

